# Generated by Django 4.2.5 on 2023-09-08 03:06

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('subjects', '0001_squashed_0009_delete_contactold'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='DataRevocationRequest',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('type', models.PositiveSmallIntegerField(choices=[(0, 'All data'), (1, 'Contact data')], verbose_name='Type')),
                ('contact', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='subjects.contact', verbose_name='Contact')),
                ('creator', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL, verbose_name='Creator')),
            ],
            options={
                'verbose_name': 'Data revocation request',
                'verbose_name_plural': 'Data revocation requests',
            },
        ),
        migrations.CreateModel(
            name='DataAccessRequest',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('contact', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='subjects.contact', verbose_name='Contact')),
                ('creator', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL, verbose_name='Creator')),
            ],
            options={
                'verbose_name': 'Data access request',
                'verbose_name_plural': 'Data access requests',
            },
        ),
    ]
